==> haskell-haddock-library-1.7.0-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-haddock-library.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haddock-library
version: 1.7.0
id: haddock-library-1.7.0-28BCFtISjCmJlR2gBkYVx7
key: haddock-library-1.7.0-28BCFtISjCmJlR2gBkYVx7
license: BSD-3-Clause
maintainer: Alec Theriault <alec.theriault@gmail.com>, Alex Biehl <alexbiehl@gmail.com>, Simon Hengel <sol@typeful.net>, Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>
homepage: http://www.haskell.org/haddock/
synopsis: Library exposing some functionality of Haddock.
description:
    Haddock is a documentation-generation tool for Haskell
    libraries. These modules expose some functionality of it
    without pulling in the GHC dependency. Please note that the
    API is likely to change so specify upper bounds in your
    project. For interacting with Haddock
    itself, see the [haddock package](https://hackage.haskell.org/package/haddock).
category: Documentation
abi: cfd7251b1422b3a7112d7a136d290bad
exposed: True
exposed-modules:
    Documentation.Haddock.Doc Documentation.Haddock.Markup
    Documentation.Haddock.Parser Documentation.Haddock.Types
    Documentation.Haddock.Utf8
hidden-modules: Documentation.Haddock.Parser.Util
                Documentation.Haddock.Parser.Monad
import-dirs: /usr/lib/ghc-8.6.4/site-local/haddock-library-1.7.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/haddock-library-1.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/haddock-library-1.7.0
hs-libraries: HShaddock-library-1.7.0-28BCFtISjCmJlR2gBkYVx7
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    parsec-3.1.13.0 text-1.2.3.1 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-haddock-library/html/haddock-library.haddock
haddock-html: /usr/share/doc/haskell-haddock-library/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-haddock-library-1.7.0-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-haddock-library.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haddock-library
version: 1.7.0
id: haddock-library-1.7.0-WOZd7yalWlG1siytN885s
key: haddock-library-1.7.0-WOZd7yalWlG1siytN885s
license: BSD-3-Clause
maintainer: Alec Theriault <alec.theriault@gmail.com>, Alex Biehl <alexbiehl@gmail.com>, Simon Hengel <sol@typeful.net>, Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>
homepage: http://www.haskell.org/haddock/
synopsis: Library exposing some functionality of Haddock.
description:
    Haddock is a documentation-generation tool for Haskell
    libraries. These modules expose some functionality of it
    without pulling in the GHC dependency. Please note that the
    API is likely to change so specify upper bounds in your
    project. For interacting with Haddock
    itself, see the [haddock package](https://hackage.haskell.org/package/haddock).
category: Documentation
abi: c1bc9cfec01e00281de96c5e0dd6cd86
exposed: True
exposed-modules:
    Documentation.Haddock.Doc Documentation.Haddock.Markup
    Documentation.Haddock.Parser Documentation.Haddock.Types
    Documentation.Haddock.Utf8
hidden-modules: Documentation.Haddock.Parser.Util
                Documentation.Haddock.Parser.Monad
import-dirs: /usr/lib/ghc-8.6.4/site-local/haddock-library-1.7.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/haddock-library-1.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/haddock-library-1.7.0
hs-libraries: HShaddock-library-1.7.0-WOZd7yalWlG1siytN885s
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    parsec-3.1.13.0 text-1.2.3.1 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-haddock-library/html/haddock-library.haddock
haddock-html: /usr/share/doc/haskell-haddock-library/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
